=begin
(c) TIG 2013
Script:
TIG-exportDCs2csv[2].rb
Type:
  TIG.exportDCs2csv2
in the Ruby Console to run it.
OR use
  Plugins menu > TIG.exportDCs2csv2
Exports all Selected DCs data into a file, as:
  Name,LenX,LenY,LenZ,Material
It uses the 'mm' for the units.
'CSV' file - in the model's folder and named after the model thus:
ModelName.skp >>> ModelName-DCs.csv
If a new model is unsaved the current directory receives the new file.
Edit sep="," if something other than separating comma is desired e.g. ';'
Make sep="\t" if a TSV file is desired and change ext="csv" to ext="tsv".
Version:
1.0 20131116 First issue.
=end
require('sketchup.rb')
###
module TIG
  unless file_loaded?(__FILE__)
	UI.menu("Plugins").add_item("TIG.exportDCs2csv2"){TIG.exportDCs2csv2()}
  end
  file_loaded(__FILE__)
  def self.exportDCs2csv2()
    sep="," ### <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
    ext="csv" ### <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
    model=Sketchup.active_model
	ss=model.selection
	insts=ss.grep(Sketchup::ComponentInstance).find_all{|inst|
		inst.definition.attribute_dictionary("dynamic_attributes")
	}
    unless insts[0]
        UI.messagebox("No DCs were selected.\nExiting.")
	    return nil
    end#if
    data=[]
    insts.each{|inst|
		defn=inst.definition
		name=defn.name.tr(sep, "_")
		lenx=defn.get_attribute("dynamic_attributes", "lenx", 0).to_f.to_mm.to_s
		leny=defn.get_attribute("dynamic_attributes", "leny", 0).to_f.to_mm.to_s
		lenz=defn.get_attribute("dynamic_attributes", "lenz", 0).to_f.to_mm.to_s
		matl=defn.get_attribute("dynamic_attributes", "material", "").to_s
		dat = "#{name}#{sep}#{lenx}#{sep}#{leny}#{sep}#{lenz}#{sep}#{matl}"
		data << dat
    }
    path=model.path
    if path==""
      path=Dir.pwd
      title="Untitled"
    else
      path=File.dirname(path)
      title=model.title
    end#if
    ofile=File.join(path, "#{title}-DCs.#{ext}").tr("\\","/")
    begin
      file=File.new(ofile, "w")
    rescue### trap if open
      UI.messagebox("File:\n\n  #{ofile}\n\nCannot be written - it is probably already open.\nClose it and try making it again...\n\nExiting...")
	  return nil
    end
    data.each{|dat| file.puts(dat) }
    file.close
	###
    puts "#{data.length.to_s} DCs written to\n#{ofile}"
    puts "DONE."
    begin
      UI.openURL("file:///#{ofile}")
    rescue
    end
  end#def
end#module
###
